==> kubernetes-model-autoscaling-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerBehaviorFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HorizontalPodAutoscalerBehaviorFluent<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends BaseFluent<A>{
  public HorizontalPodAutoscalerBehaviorFluent() {
  }
  
  public HorizontalPodAutoscalerBehaviorFluent(HorizontalPodAutoscalerBehavior instance) {
    this.copyInstance(instance);
  }
  private HPAScalingRulesBuilder scaleDown;
  private HPAScalingRulesBuilder scaleUp;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HorizontalPodAutoscalerBehavior instance) {
    instance = (instance != null ? instance : new HorizontalPodAutoscalerBehavior());
    if (instance != null) {
          this.withScaleDown(instance.getScaleDown());
          this.withScaleUp(instance.getScaleUp());
          this.withScaleDown(instance.getScaleDown());
          this.withScaleUp(instance.getScaleUp());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public HPAScalingRules buildScaleDown() {
    return this.scaleDown != null ? this.scaleDown.build() : null;
  }
  
  public A withScaleDown(HPAScalingRules scaleDown) {
    this._visitables.remove(this.scaleDown);
    if (scaleDown != null) {
        this.scaleDown = new HPAScalingRulesBuilder(scaleDown);
        this._visitables.get("scaleDown").add(this.scaleDown);
    } else {
        this.scaleDown = null;
        this._visitables.get("scaleDown").remove(this.scaleDown);
    }
    return (A) this;
  }
  
  public boolean hasScaleDown() {
    return this.scaleDown != null;
  }
  
  public ScaleDownNested<A> withNewScaleDown() {
    return new ScaleDownNested(null);
  }
  
  public ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item) {
    return new ScaleDownNested(item);
  }
  
  public ScaleDownNested<A> editScaleDown() {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(null));
  }
  
  public ScaleDownNested<A> editOrNewScaleDown() {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(new HPAScalingRulesBuilder().build()));
  }
  
  public ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item) {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(item));
  }
  
  public HPAScalingRules buildScaleUp() {
    return this.scaleUp != null ? this.scaleUp.build() : null;
  }
  
  public A withScaleUp(HPAScalingRules scaleUp) {
    this._visitables.remove(this.scaleUp);
    if (scaleUp != null) {
        this.scaleUp = new HPAScalingRulesBuilder(scaleUp);
        this._visitables.get("scaleUp").add(this.scaleUp);
    } else {
        this.scaleUp = null;
        this._visitables.get("scaleUp").remove(this.scaleUp);
    }
    return (A) this;
  }
  
  public boolean hasScaleUp() {
    return this.scaleUp != null;
  }
  
  public ScaleUpNested<A> withNewScaleUp() {
    return new ScaleUpNested(null);
  }
  
  public ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item) {
    return new ScaleUpNested(item);
  }
  
  public ScaleUpNested<A> editScaleUp() {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(null));
  }
  
  public ScaleUpNested<A> editOrNewScaleUp() {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(new HPAScalingRulesBuilder().build()));
  }
  
  public ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item) {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerBehaviorFluent that = (HorizontalPodAutoscalerBehaviorFluent) o;
    if (!java.util.Objects.equals(scaleDown, that.scaleDown)) return false;
    if (!java.util.Objects.equals(scaleUp, that.scaleUp)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(scaleDown,  scaleUp,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scaleDown != null) { sb.append("scaleDown:"); sb.append(scaleDown + ","); }
    if (scaleUp != null) { sb.append("scaleUp:"); sb.append(scaleUp + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ScaleDownNested<N> extends HPAScalingRulesFluent<ScaleDownNested<N>> implements Nested<N>{
    ScaleDownNested(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    HPAScalingRulesBuilder builder;
    
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluent.this.withScaleDown(builder.build());
    }
    
    public N endScaleDown() {
      return and();
    }
    
  
  }
  public class ScaleUpNested<N> extends HPAScalingRulesFluent<ScaleUpNested<N>> implements Nested<N>{
    ScaleUpNested(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    HPAScalingRulesBuilder builder;
    
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluent.this.withScaleUp(builder.build());
    }
    
    public N endScaleUp() {
      return and();
    }
    
  
  }

}

==> kubernetes-model-autoscaling-6.11.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerBehaviorFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HorizontalPodAutoscalerBehaviorFluent<A extends HorizontalPodAutoscalerBehaviorFluent<A>> extends BaseFluent<A>{
  public HorizontalPodAutoscalerBehaviorFluent() {
  }
  
  public HorizontalPodAutoscalerBehaviorFluent(HorizontalPodAutoscalerBehavior instance) {
    this.copyInstance(instance);
  }
  private HPAScalingRulesBuilder scaleDown;
  private HPAScalingRulesBuilder scaleUp;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HorizontalPodAutoscalerBehavior instance) {
    instance = (instance != null ? instance : new HorizontalPodAutoscalerBehavior());
    if (instance != null) {
          this.withScaleDown(instance.getScaleDown());
          this.withScaleUp(instance.getScaleUp());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public HPAScalingRules buildScaleDown() {
    return this.scaleDown != null ? this.scaleDown.build() : null;
  }
  
  public A withScaleDown(HPAScalingRules scaleDown) {
    this._visitables.remove("scaleDown");
    if (scaleDown != null) {
        this.scaleDown = new HPAScalingRulesBuilder(scaleDown);
        this._visitables.get("scaleDown").add(this.scaleDown);
    } else {
        this.scaleDown = null;
        this._visitables.get("scaleDown").remove(this.scaleDown);
    }
    return (A) this;
  }
  
  public boolean hasScaleDown() {
    return this.scaleDown != null;
  }
  
  public ScaleDownNested<A> withNewScaleDown() {
    return new ScaleDownNested(null);
  }
  
  public ScaleDownNested<A> withNewScaleDownLike(HPAScalingRules item) {
    return new ScaleDownNested(item);
  }
  
  public ScaleDownNested<A> editScaleDown() {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(null));
  }
  
  public ScaleDownNested<A> editOrNewScaleDown() {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(new HPAScalingRulesBuilder().build()));
  }
  
  public ScaleDownNested<A> editOrNewScaleDownLike(HPAScalingRules item) {
    return withNewScaleDownLike(java.util.Optional.ofNullable(buildScaleDown()).orElse(item));
  }
  
  public HPAScalingRules buildScaleUp() {
    return this.scaleUp != null ? this.scaleUp.build() : null;
  }
  
  public A withScaleUp(HPAScalingRules scaleUp) {
    this._visitables.remove("scaleUp");
    if (scaleUp != null) {
        this.scaleUp = new HPAScalingRulesBuilder(scaleUp);
        this._visitables.get("scaleUp").add(this.scaleUp);
    } else {
        this.scaleUp = null;
        this._visitables.get("scaleUp").remove(this.scaleUp);
    }
    return (A) this;
  }
  
  public boolean hasScaleUp() {
    return this.scaleUp != null;
  }
  
  public ScaleUpNested<A> withNewScaleUp() {
    return new ScaleUpNested(null);
  }
  
  public ScaleUpNested<A> withNewScaleUpLike(HPAScalingRules item) {
    return new ScaleUpNested(item);
  }
  
  public ScaleUpNested<A> editScaleUp() {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(null));
  }
  
  public ScaleUpNested<A> editOrNewScaleUp() {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(new HPAScalingRulesBuilder().build()));
  }
  
  public ScaleUpNested<A> editOrNewScaleUpLike(HPAScalingRules item) {
    return withNewScaleUpLike(java.util.Optional.ofNullable(buildScaleUp()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerBehaviorFluent that = (HorizontalPodAutoscalerBehaviorFluent) o;
    if (!java.util.Objects.equals(scaleDown, that.scaleDown)) return false;
    if (!java.util.Objects.equals(scaleUp, that.scaleUp)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(scaleDown,  scaleUp,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scaleDown != null) { sb.append("scaleDown:"); sb.append(scaleDown + ","); }
    if (scaleUp != null) { sb.append("scaleUp:"); sb.append(scaleUp + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ScaleDownNested<N> extends HPAScalingRulesFluent<ScaleDownNested<N>> implements Nested<N>{
    ScaleDownNested(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    HPAScalingRulesBuilder builder;
    
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluent.this.withScaleDown(builder.build());
    }
    
    public N endScaleDown() {
      return and();
    }
    
  
  }
  public class ScaleUpNested<N> extends HPAScalingRulesFluent<ScaleUpNested<N>> implements Nested<N>{
    ScaleUpNested(HPAScalingRules item) {
      this.builder = new HPAScalingRulesBuilder(this, item);
    }
    HPAScalingRulesBuilder builder;
    
    public N and() {
      return (N) HorizontalPodAutoscalerBehaviorFluent.this.withScaleUp(builder.build());
    }
    
    public N endScaleUp() {
      return and();
    }
    
  
  }

}
